@@ -1,7 +1,7 @@
 /* Extended Module Player
  * Copyright (C) 1996-2007 Claudio Matsuoka and Hipolito Carraro Jr.
  *
- * $Id: it_load.c,v 1.40 2007/11/17 19:33:42 cmatsuoka Exp $
+ * $Id: it_load.c,v 1.43 2007/12/05 11:10:55 cmatsuoka Exp $
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -102,6 +102,9 @@ static void xlat_fx(int c, struct xxm_event *e)
 	else
 	    e->fxp = arpeggio_val[c];
 	break;
+    case FX_JUMP:
+	e->fxp = ord_xlat[e->fxp];
+	break;
     case FX_VIBRATO:		/* Old or new vibrato */
 	if (new_fx)
 	    e->fxt = FX_FINE2_VIBRA;
@@ -291,12 +294,18 @@ static int it_load(struct xmp_context *ctx, FILE *f, const int start)
 	else
 	    ifh.chvol[i] = 0;
 
-	m->xxc[i].pan = ifh.flags & IT_STEREO ?
-	    ((int) ifh.chpan[i] * 0x80 >> 5) & 0xff : 0x80;
+	if (ifh.flags & IT_STEREO) {
+	    m->xxc[i].pan = (int)ifh.chpan[i] * 0x80 >> 5;
+	    if (m->xxc[i].pan > 0xff)
+		m->xxc[i].pan = 0xff;
+	} else {
+	    m->xxc[i].pan = 0x80;
+	}
 
 	m->xxc[i].vol = ifh.chvol[i];
     }
-    fread (m->xxo, 1, m->xxh->len, f);
+    fread(m->xxo, 1, m->xxh->len, f);
+    clean_s3m_seq(m->xxh, m->xxo);
 
     new_fx = ifh.flags & IT_OLD_FX ? 0 : 1;
 
@@ -829,15 +838,19 @@ static int it_load(struct xmp_context *ctx, FILE *f, const int start)
 	    event = c >= m->xxh->chn ? &dummy : &EVENT (i, c, r);
 	    if (mask[c] & 0x01) {
 		fread (&b, 1, 1, f);
+
+		if (b > 0x7f && b < 0xfd)
+			b = 0;
+
 		switch (b) {
 		case 0xff:	/* key off */
-		    b = 0x61;
+		    b = XMP_KEY_OFF;
 		    break;
 		case 0xfe:	/* cut */
-		    b = 0x62;
+		    b = XMP_KEY_CUT;
 		    break;
 		case 0xfd:	/* fade */
-		    b = 0x63;
+		    b = XMP_KEY_FADE;
 		    break;
 		default:
 		    if (b < 11)
@@ -845,8 +858,6 @@ static int it_load(struct xmp_context *ctx, FILE *f, const int start)
 		    else
 			b -= 11;
 		}
-		if (b > 0x62)
-		    b = 0;
 		lastevent[c].note = event->note = b;
 		pat_len--;
 	    }
@@ -905,7 +916,7 @@ static int it_load(struct xmp_context *ctx, FILE *f, const int start)
 
     m->xxh->chn = max_ch + 1;
     m->fetch |= ifh.flags & IT_USE_INST ? XMP_MODE_IT : XMP_MODE_ST3;
-    m->fetch |= XMP_CTL_VIRTUAL | XMP_CTL_FILTER;
+    m->fetch |= XMP_CTL_INSPRI | XMP_CTL_VIRTUAL | XMP_CTL_FILTER;
 
     reportv(ctx, 0, "\n");
 
