@@ -1,7 +1,7 @@
 /* Extended Module Player
  * Copyright (C) 1996-2007 Claudio Matsuoka and Hipolito Carraro Jr
  *
- * $Id: xm_load.c,v 1.32 2007/11/15 22:36:54 cmatsuoka Exp $
+ * $Id: xm_load.c,v 1.35 2007/12/06 00:10:36 cmatsuoka Exp $
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -113,9 +113,13 @@ static int xm_load(struct xmp_context *ctx, FILE *f, const int start)
 	fix_loop = 1;
     }
 
-    if (!strncmp(tracker_name, "FastTracker v 2.00", 18)) {
+    /* See MMD1 loader for explanation */
+    if (!strncmp(tracker_name, "MED2XM by J.Pynnone", 19))
+	if (m->xxh->bpm <= 10)
+	    m->xxh->bpm = 125 * (0x35 - m->xxh->bpm * 2) / 33;
+
+    if (!strncmp(tracker_name, "FastTracker v 2.00", 18))
 	strcpy(tracker_name, "old ModPlug Tracker");
-    }
 
     snprintf(m->type, XMP_NAMESIZE, "XM %d.%02d (%s)",
 			xfh.version >> 8, xfh.version & 0xff, tracker_name);
@@ -182,6 +186,10 @@ load_patterns:
 		    event->fxt = *pat++;
 		    event->fxp = *pat++;
 		}
+
+		if (event->note == 0x61)
+		    event->note = XMP_KEY_OFF;
+
 		if (!event->vol)
 		    continue;
 
