@@ -1,7 +1,7 @@
 /* Extended Module Player
  * Copyright (C) 1996-2007 Claudio Matsuoka and Hipolito Carraro Jr
  *
- * $Id: main.c,v 1.35 2007/11/26 19:04:48 cmatsuoka Exp $
+ * $Id: main.c,v 1.39 2007/12/05 23:39:27 cmatsuoka Exp $
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -34,7 +34,11 @@
 #include <signal.h>
 #include <unistd.h>
 
-#ifdef __amigaos4__
+#ifdef __AROS__
+#define __AMIGA__
+#endif
+
+#ifdef __AMIGA__
 #undef HAVE_TERMIOS_H
 #define __USE_INLINE__
 #include <proto/dos.h>
@@ -147,7 +151,7 @@ static void sigtstp_handler()
 
 static void sigcont_handler()
 {
-#ifndef __amigaos4__
+#ifndef __AMIGA__
     background = (tcgetpgrp(0) == getppid());
 #endif
 
@@ -269,17 +273,19 @@ static void process_echoback(unsigned long i)
     k = read(0, &cmd, 1);
 #elif defined WIN32
     k = cmd = kbhit() ? getch() : 0;
-#else
+#elif defined __AMIGA__
     /* Amiga CLI */
-    if (WaitForChar(Input(), 1)) {
-	char c;
-#ifndef __amigaos4__
-	Read(in, &c, 1);
-#else
-	Read(stdin, &c, 1);
-#endif
-	cmd = k = c;
+    {
+	BPTR in = Input();
+        k = cmd = 0;
+        if (WaitForChar(in, 1)) {
+	    char c;
+	    Read(in, &c, 1);
+	    cmd = k = c;
+	}
     }
+#else
+    k = cmd = 0;
 #endif
 
     if (k > 0) {
