@@ -1,7 +1,7 @@
 /* Extended Module Player
  * Copyright (C) 1996-2007 Claudio Matsuoka and Hipolito Carraro Jr
  *
- * $Id: load.c,v 1.62 2007/11/26 11:47:00 cmatsuoka Exp $
+ * $Id: load.c,v 1.69 2007/12/06 20:22:56 cmatsuoka Exp $
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
@@ -38,8 +38,10 @@ int decrunch_sqsh	(FILE *, FILE *);
 int decrunch_pp		(FILE *, FILE *);
 int decrunch_mmcmp	(FILE *, FILE *);
 int decrunch_oxm	(FILE *, FILE *);
+int decrunch_xfd	(FILE *, FILE *);
 int decrunch_pw		(FILE *, FILE *);
 int test_oxm		(FILE *);
+char *test_xfd		(unsigned char *, int);
 int pw_check		(unsigned char *, int);
 
 #define BUILTIN_PP	0x01
@@ -50,10 +52,19 @@ int pw_check		(unsigned char *, int);
 #define BUILTIN_ARCFS	0x06
 #define BUILTIN_S404	0x07
 #define BUILTIN_OXM	0x08
+#define BUILTIN_XFD	0x09
 
 
 #define TMP_SIZE 512
 
+#if defined __EMX__ || defined WIN32
+#define REDIR_STDERR "2>NUL"
+#elif defined unix
+#define REDIR_STDERR "2>/dev/null"
+#else
+#define REDIR_STDERR
+#endif
+
 static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
 {
     struct xmp_options *o = &ctx->o;
@@ -73,19 +84,21 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
     b = calloc(1, PW_TEST_CHUNK);
     fread(b, 1, PW_TEST_CHUNK, *f);
 
+#if defined __AMIGA__ && !defined __AROS__
+    if (packer = test_xfd(b,PW_TEST_CHUNK)) {
+	builtin = BUILTIN_XFD;
+    } else
+#endif
     if (b[0] == 'P' && b[1] == 'K') {
 	packer = "Zip";
-#ifdef __EMX__
 	cmd = "unzip -pqqC \"%s\" -x readme '*.diz' '*.nfo' '*.txt' "
-		"'*.exe' '*.com' 2>NUL";
-#else
-	cmd = "unzip -pqqC \"%s\" -x readme '*.diz' '*.nfo' '*.txt' "
-		"'*.exe' '*.com' 2>/dev/null";
-#endif
+		"'*.exe' '*.com' " REDIR_STDERR;
     } else if (b[2] == '-' && b[3] == 'l' && b[4] == 'h') {
 	packer = "LHa";
-#ifdef __EMX__
+#if defined __EMX__
 	fprintf( stderr, "LHA for OS/2 does NOT support output to stdout.\n" );
+#elif defined __AMIGA__
+	cmd = "lha p -q \"%s\"";
 #endif
 	cmd = "lha -pq \"%s\"";
     } else if (b[0] == 31 && b[1] == 139) {
@@ -128,7 +141,7 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
 	packer = "rar";
 	cmd = "unrar p -inul -xreadme -x*.diz -x*.nfo -x*.txt "
 	    "-x*.exe -x*.com \"%s\"";
-#if !defined __MINGW32__ && !defined __amigaos4__
+#if !defined WIN32 && !defined __AMIGA__
     } else if (test_oxm(*f) == 0) {
 	packer = "oggmod";
 	builtin = BUILTIN_OXM;
@@ -178,7 +191,9 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
 	return 0;
     }
 
-    reportv(ctx, 0, "Depacking %s file... ", packer);
+    /* TODO: move pw to loaders -- add better Arc test above */
+    if (builtin != BUILTIN_PW)
+       reportv(ctx, 0, "Depacking %s file... ", packer);
 
     if ((fd = mkstemp(temp)) < 0) {
 	if (o->verbosity > 0)
@@ -200,7 +215,11 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
 	line = malloc(lsize);
 	snprintf(line, lsize, cmd, *s);
 
-	if ((p = popen (line, "r")) == NULL) {
+#ifdef WIN32
+	if ((p = popen(line, "rb")) == NULL) {
+#else
+	if ((p = popen(line, "r")) == NULL) {
+#endif
 	    reportv(ctx, 0, "failed\n");
 	    fclose(t);
 	    free(line);
@@ -236,10 +255,15 @@ static int decrunch(struct xmp_context *ctx, FILE **f, char **s)
 	case BUILTIN_MMCMP:    
 	    res = decrunch_mmcmp(*f, t);
 	    break;
-#if !defined __MINGW32__ && !defined __amigaos4__
+#if !defined __MINGW32__ && !defined __AMIGA__
 	case BUILTIN_OXM:
 	    res = decrunch_oxm(*f, t);
 	    break;
+#endif
+#ifdef AMIGA
+	case BUILTIN_XFD:
+	    res = decrunch_xfd(*f, t);
+	    break;
 #endif
 	case BUILTIN_PW:
 	    res = decrunch_pw(*f, t);
