@@ -1,9 +1,11 @@
 /* Extended Module Player
- * Copyright (C) 1996,1997 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996,2001 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU General Public License. See doc/COPYING
  * for more information.
+ *
+ * $Id: period.c,v 1.10 2007/11/11 12:54:16 cmatsuoka Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -15,6 +17,7 @@
 #include "xmpi.h"
 #include "period.h"
 
+#include <math.h>
 
 /* Amiga periods */
 static int period_amiga[] = {
@@ -35,36 +38,29 @@ static int period_amiga[] = {
 };
 
 
-/* Get period from note and finetune */
-/* Finetune interpolation moved to period_to_bend () --claudio */
-int note_to_period (int n, int f, int type)
+/* Get period from note */
+/* Finetune moved to period_to_bend () --claudio */
+inline int note_to_period(int n, int type)
 {
-    int *t = period_amiga;
+    double d = (double)n;
 
-    if (type)
-	return (((120 - n) << 7) - f) >> 3;	/* Linear */
-    n += !((f < 0) && (f += 0x80));
-    t += ((n % 12) << 3) + (f >> 4);
-    return *t >> (n / 12);			/* Amiga */
+    return type ?
+	(120 - n) << 4 :			/* Linear */
+        (int)(6847.0 / pow(2, d / 12));		/* Amiga */
 }
 
 
-/* Same thing, optimized for the software mixer */
-int note_to_period2 (int n, int b)
+/* For the software mixer */
+int note_to_period_mix(int n, int b)
 {
-    int *t = period_amiga;
-    int f = ((b % 100) << 7) / 100;
-
-    if ((n += !((b < 0) && (f += 0x80)) + b / 100) < 0)
-	n = 0;
-    t += ((n % 12) << 3) + (f >> 4);
-    return ((*t << 4) + (*t++ - *t) * (f & 0xf)) >> (n / 12);
+    double d = (double)n + (double)b / 100;
+    return (int)(16.0 * 6847.0 / pow(2, d / 12));
 }
 
 
 /* Get note from period using the Amiga frequency table */
-/* This function is currently used only by the MOD loader */
-int period_to_note (int p)
+/* This function is used only by the MOD loader */
+int period_to_note(int p)
 {
     int n, f, *t = period_amiga + MAX_NOTE;
 
@@ -78,9 +74,10 @@ int period_to_note (int p)
 
 
 /* Get pitchbend from base note and period */
-int period_to_bend (int p, int n, int f, int a, int g, int type)
+int period_to_bend(int p, int n, int f, int a, int g, int type)
 {
-    int b, *t = period_amiga + MAX_NOTE;
+    int b;
+    double d;
 
     if (!n)
 	return 0;
@@ -91,41 +88,34 @@ int period_to_bend (int p, int n, int f, int a, int g, int type)
 	if (p < AMIGA_LIMIT_UPPER)
 	    p = AMIGA_LIMIT_UPPER;
     }
+
     if (type) {
-	b = (100 * (((120 - n) << 4) - p)) >> 4;	/* Linear */
+	/* b = (100 * (((120 - n) << 4) - p)) >> 4 + f * 100 / 128; */
+	b = 100 * (8 * (((120 - n) << 4) - p) + f) / 128;	/* Linear */
 	return g ? b / 100 * 100 : b;
     }
+
     if (p < MIN_PERIOD_A)
 	p = MIN_PERIOD_A;
 
-    /* Fixup for panic.s3m  (from Toru Egashira's NSPmod) */
-    for (n = NOTE_B0 - 1 - n; p <= (MAX_PERIOD / 2); n += 12, p <<= 1);
+    d = note_to_period(n, 0);
+    b = 100.0 * ((1536.0 * log(d / p) / M_LN2) + f) / 128;
 
-    for (; p > *t; t -= 8, n--);
-    b = 100 * n + (100 * (*t - p) / (*t - *(t + 8))) +
-	((f - 128) % 16) * 100 / 128 * (f < 0 ? -1 : 1);
     return g ? b / 100 * 100 : b;	/* Amiga */
 }
 
 
-/* Convert finetune=1200*log2 (C2SPD/8363)) using the Amiga frequency table.
+/* Convert finetune = 1200 * log2(C2SPD/8363))
  *
- *      c = (1200.0 * log (c2spd)-1200.0 * log (c4_rate))/M_LN2;
+ *      c = (1200.0 * log(c2spd) - 1200.0 * log(c4_rate)) / M_LN2;
  *      xpo = c/100;
  *      fin = 128 * (c%100) / 100;
  */
-void c2spd_to_note (int c2spd, int *n, int *f)
+void c2spd_to_note(int c2spd, int *n, int *f)
 {
-    int note, finetune, *t = period_amiga;
+    int c;
 
-    if (!(c2spd = (140 * c2spd) >> 8)) {
-	*n = *f = 0;
-	return;
-    }
-    for (note = 8; c2spd <= (MAX_PERIOD / 2); note -= 12, c2spd <<= 1);
-    for (; c2spd > MAX_PERIOD; note += 12, c2spd >>= 1);
-    for (; *t > c2spd; t += 8, note--);
-    for (finetune = -1; *t < c2spd; t--, finetune++);
-    *n = note;
-    *f = finetune << 4;
+    c = (int)(1536.0 * log((double)c2spd / 8363) / M_LN2);
+    *n = c / 128;
+    *f = c % 128;
 }
