@@ -5,7 +5,7 @@
  * under the terms of the GNU General Public License. See doc/COPYING
  * for more information.
  *
- * $Id: player.c,v 1.48 2007/11/01 10:48:39 cmatsuoka Exp $
+ * $Id: player.c,v 1.53 2007/12/05 12:24:42 cmatsuoka Exp $
  */
 
 /*
@@ -245,6 +245,7 @@ static int module_fetch(struct xmp_context *ctx, struct xxm_event *e, int chn, i
     if (e->ins) {
 	ins = e->ins - 1;
 	flg = NEW_INS | RESET_VOL | RESET_ENV;
+	xc->fadeout = 0x8000;	/* for painlace.mod pat 0 ch 3 echo */
 	xc->per_flags = 0;
 
 	if (m->fetch & XMP_CTL_OINSMOD) {
@@ -326,7 +327,7 @@ static int module_fetch(struct xmp_context *ctx, struct xxm_event *e, int chn, i
     if ((uint32)ins < m->xxh->ins && m->xxih[ins].nsm)
 	flg |= IS_VALID;
 
-    if ((uint32)key < 0x61 && key--) {
+    if ((uint32)key < XMP_KEY_OFF && key--) {
 	xc->key = key;
 
         if (flg & IS_VALID) {
@@ -418,7 +419,7 @@ static int module_fetch(struct xmp_context *ctx, struct xxm_event *e, int chn, i
         return XMP_OK;
 
     if (TEST(RESET_ENV)) {
-        xc->fadeout = 0x8000;
+        /* xc->fadeout = 0x8000; -- moved to fetch */
         RESET(RELEASE | FADEOUT);
         xc->gvl = XXI[XXIM.ins[xc->key]].gvl;   /* #?# Onde eu coloco isso? */
         xc->insvib_swp = XXI->vsw;              /* #?# Onde eu coloco isso? */
@@ -789,10 +790,8 @@ int xmpi_player_start(struct xmp_context *ctx)
     p->gvol_base = m->volbase;
     ord = o->start;
 
-    /* S3M skip in first pattern (gaming.s3m) or
-     * invalid patterns at start (the seventh laboratory.it)
-     */
-    while (ord < m->xxh->len && m->xxo[ord] >= m->xxh->pat /*== 254*/)
+    /* Skip invalid patterns at start (the seventh laboratory.it) */
+    while (ord < m->xxh->len && m->xxo[ord] >= m->xxh->pat)
 	ord++;
 
     m->volume = m->xxo_info[ord].gvl;
@@ -823,14 +822,14 @@ next_order:
 	    ord = ((uint32)m->xxh->rst > m->xxh->len ||
 		(uint32)m->xxo[m->xxh->rst] >= m->xxh->pat) ?  0 : m->xxh->rst;
 	    m->volume = m->xxo_info[ord].gvl;
-	    if (m->xxo[ord] == 0xff)
-		break;
 	}
+
+	/* Skip invalid patterns */
 	if (m->xxo[ord] >= m->xxh->pat) {
-	    if (m->xxo[ord] == 0xfe)		/* S3M skips pattern 0xfe */
-		continue;
-	    if (m->xxo[ord] == 0xff)		/* S3M uses 0xff as end mark */
-		ord = m->xxh->len;
+#if 0
+           if (m->xxo[ord] == 0xff)            /* S3M uses 0xff as end mark */
+                ord = m->xxh->len;
+#endif
 	    continue;
 	}
 
